pub struct UpdateRequest<'a> {
pub usergroup: &'a str,
pub users: &'a str,
pub include_count: Option<bool>,
}Fields
usergroup: &'a strThe encoded ID of the User Group to update.
users: &'a strA comma separated string of encoded user IDs that represent the entire list of users for the User Group.
include_count: Option<bool>Include the number of users in the User Group.